==> shellcheck-0.5.0-24-x86_64.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.5.0
id: ShellCheck-0.5.0-8sb8awPP4VXFOzng4LJbET
key: ShellCheck-0.5.0-8sb8awPP4VXFOzng4LJbET
license: GPL-3.0-only
maintainer: vidar@vidarholen.net
author: Vidar Holen
homepage: https://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
abi: a71e556e06fb1fdd49c1db3ea125bd6b
exposed: True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Formatter.CheckStyle
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/ShellCheck-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/ShellCheck-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/ShellCheck-0.5.0
hs-libraries: HSShellCheck-0.5.0-8sb8awPP4VXFOzng4LJbET
depends:
    aeson-1.3.1.1-IVr04sg3p2P8j1rEsumT73 base-4.11.1.0
    bytestring-0.10.8.2 containers-0.5.11.0 directory-1.3.1.5 mtl-2.2.2
    parsec-3.1.13.0 regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr process-1.6.3.0
abi-depends: aeson-1.3.1.1-IVr04sg3p2P8j1rEsumT73=a6f953f9dda8218f3e00f48fbc968e32
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=5e8070c089035e31a54af0f52dd81fff
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> shellcheck-0.5.0-37-x86_64.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.5.0
id: ShellCheck-0.5.0-LGhRaYBsMI04xGJAomXzFD
key: ShellCheck-0.5.0-LGhRaYBsMI04xGJAomXzFD
license: GPL-3.0-only
maintainer: vidar@vidarholen.net
author: Vidar Holen
homepage: https://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
abi: 4700e9d29d2b6c89f1a4732f2ef5cb8a
exposed: True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Formatter.CheckStyle
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/ShellCheck-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/ShellCheck-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/ShellCheck-0.5.0
hs-libraries: HSShellCheck-0.5.0-LGhRaYBsMI04xGJAomXzFD
depends:
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y base-4.11.1.0
    bytestring-0.10.8.2 containers-0.5.11.0 directory-1.3.1.5 mtl-2.2.2
    parsec-3.1.13.0 regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr process-1.6.3.0
abi-depends: aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=5e8070c089035e31a54af0f52dd81fff
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
